Address class

Constructors

Address({String line1 = '', String line2 = '', String city = '', String state = '', String postalCode = '', String country = '', String? text})
const
Address.empty()
const

Properties

city String
final
country String
final
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setter
line1 String
final
line2 String
final
postalCode String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String
final
text String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, String>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited