country property
Limit results to one or more countries. Permitted values are ISO 3166 alpha 2 country codes separated by commas.
Check the full list of supported countries for the MapBox API
Implementation
final String? country;
Limit results to one or more countries. Permitted values are ISO 3166 alpha 2 country codes separated by commas.
Check the full list of supported countries for the MapBox API
final String? country;